% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/glads_funcs.R
\name{admix}
\alias{admix}
\title{Admixture}
\usage{
admix(x, mr, taxa, dd = FALSE, eqvm = FALSE, nmin = 10)
}
\arguments{
\item{x}{List of objects of class \code{"struct"} with the genetic structure of populations.}

\item{mr}{A square matrix with the migration rate among populations.}

\item{taxa}{Vector of integers coding the taxon 'id' of each population.}

\item{dd}{A logical value. If \code{TRUE} the admixture between taxa is density-dependent (see Details). The default value is \code{FALSE}}

\item{eqvm}{A logical value representing equivalent migration between taxa. If \code{TRUE} the resulting individuals migrating between taxa are equivalent to the number of migrants sent by the smaller population. The default value is \code{FALSE}}

\item{nmin}{An integer defining the minimum population size for starting the admixture between different taxa. The default value is 10.}
}
\value{
A square matrx.
}
\description{
This function modify the migration matrix to incorporate density-dependent or density-independent gene flow between taxa.
}
\details{
This function returns a square matrix with the migration rate within and between taxa. The admixture is computed in a similar way as in SPLATCHE3 (Currat et al., 2019), in which the populations are subdivided by the number of taxa in a grid of demes.

The geographic structure of the subpopulations is defined by the migration rate matrix, with values that may corresponds to neighbor subpopulations or to long-distance dispersal (LDD).
The matrix has migration rate values for each pair of subpopulations (migration['from', 'to']). A value of \eqn{m_{ij} = 0} means no migration and thus no gene flow between subpopulations \eqn{i} and \eqn{j}, while a value of 0.5 means random migration between them.
Because the subpopulations of a given taxon could corresponds geographically to subpopulations of another taxon (e.g., two grid of demes equally located and belonging to two taxa), the migration rate have to be updated by the likelihood of admixture (\eqn{A_{ij}}). If \eqn{dd = TRUE} a density-dependent admixture between subpopulations \eqn{i} and \eqn{j} that belongs to different taxa is computed (\eqn{A_{ij}}).
This is done in a similar way as in Currat et al. (2019):
\deqn{A_{ij} = \frac{4m_{ij}N_iN_j}{(N_i+N_j)^2}}
Where \eqn{N_i} and \eqn{N_j} are the population sizes of population \eqn{i} and \eqn{j}. The main different with the implementation of Currat et al. (2019) is that the density-dependent admixture is multiplied by \eqn{4} instead of \eqn{2}. This is because the admixture rate is defined by \eqn{m_{ij}} instead of \eqn{\gamma_{ij}} that is used in Currat et al (2019). The last  parameter has a value of \eqn{1} coding for random mating, while in this approach this occurs at \eqn{m_{ij}=0.5}.
}
\examples{
##Two taxa inhabiting three demes (six subpopulations in total).
initial.population.size.taxon1=40
initial.population.size.taxon2=20
n.loci=5
n.alleles.per.locus=2
npop=6
ndemes=3
taxa.id=c(rep(1, ndemes), rep(2, ndemes))
migration.rate <- matrix(rep(0.01, npop*npop), ncol=6); diag(migration.rate) <- 1

taxon1_deme1 <- taxon1_deme2 <- taxon1_deme3 <- initial.struct(initial.population.size.taxon1,
                n.loci,n.alleles.per.locus, taxon = list(pos=3:4, id=1))
taxon2_deme1 <- taxon2_deme2 <- taxon2_deme3 <- initial.struct(initial.population.size.taxon2,
                n.loci,n.alleles.per.locus, taxon = list(pos=3:4, id=2))

struct <- list(taxon1_deme1, taxon1_deme2, taxon1_deme3, taxon2_deme1, taxon2_deme2, taxon2_deme3)

new.migration.rate <- admix(x = struct, mr = migration.rate, taxa = taxa.id, dd=TRUE)
}
\references{
Currat M, Arenas M, Quilodrán CS, Excoffier L and N Ray N.  (2019).
SPLATCHE3: simulation of serial genetic data under spatially explicit evolutionary scenarios including long-distance dispersal.
\emph{Bioinformatics 35(21):4480–4483.}.
\doi{10.1093/bioinformatics/btz311}.
}
\seealso{
\code{\link{evolve}} \code{\link{mmatrix}}
}
\keyword{internal}
