% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/glads_funcs.R
\name{mmatrix}
\alias{mmatrix}
\title{Migration matrix}
\usage{
mmatrix(migration.rate, npop)
}
\arguments{
\item{migration.rate}{A single value setting the migration rate among all populations, or a square matrix of order equal to the number of populations. The last matrix has migration rate values for each pair of populations (migration['from', 'to']). Alternatively, this parameter could be a list in which the first element is a vector displaying the 't' generations that have a change of migration pattern. The following 't+1' elements are the migration rates before the change of migration pattern (single values and/or square matrices). A value of \eqn{m_{ij} = 0} means no migration and thus no gene flow between populations \eqn{i} and \eqn{j}, while a value of 0.5 means random migration (and hence random reproduction) between them. This parameter is ignored for single population simulations. The default value is NULL with no migration among populations.}

\item{npop}{number of simulated populations.}
}
\value{
An object of class \code{"mmatrix"} or an array
}
\description{
A matrix with the pairwise migration values between populations.
}
\details{
The function is used internally in the function evolve(). The rows and columns are the simulated populations. Each element of the array is a double defining the migration value between population pairs. The different dimensions of the array represents changes of migration pattern across generations.
}
\examples{
# Five populations with equal migration rates across all generations
npop <- 5 #number of populations
mr <- 0.1 #migration rate between populations
m<-mmatrix(mr, npop)


# Variable migration rate over time
mr1 <- 0.01 #initial migration rate
mr2 <- matrix(rep(0.02, npop*npop), nrow = npop, ncol = npop, byrow = TRUE); diag(mr2) <- 1
mr3 <- 0
mchange <- c(10, 20) #a change of migration pattern occurs after these generations
m<-mmatrix(list(mchange, mr1, mr2,mr3), npop)

\dontrun{
#Plotting connected populations
require(igraph)

gm1 <- graph_from_adjacency_matrix(m[,,1], mode = "directed",weighted=TRUE)
gm2 <- graph_from_adjacency_matrix(m[,,2], mode = "directed",weighted=TRUE)
gm3 <- graph_from_adjacency_matrix(m[,,3], mode = "directed",weighted=TRUE)

op<- par(mfcol=c(1,3))
gm1 <- graph_from_adjacency_matrix(m[,,1], mode = "directed",weighted=TRUE)
gm2 <- graph_from_adjacency_matrix(m[,,2], mode = "directed",weighted=TRUE)
gm3 <- graph_from_adjacency_matrix(m[,,3], mode = "directed",weighted=TRUE)

plot(gm1)
plot(gm2)
plot(gm3)
par(op)
}
}
\seealso{
\code{\link{evolve}}
}
\keyword{internal}
